% A wrapper for function TPXO_ROMS.m.

%t0 can be any time of day not necessarily 00:00 
%lengthSim is the approximate anticipated length of model run (days) (f & u are computed at mid-point).
%fnGRD is your ROMS grid file.
%TPXO2ROMS will write to fnOut.
%t0-datenum(1968,5,23); is for the ROMS *.in file if using TIME_REF=-2.

%Available choices for HarmonicNames:  
%'MM' 'MF' 'Q1' 'O1' 'P1' 'K1' 'S1' 'N2' 'M2' 'S2' 'K2' 'MN4' 'M4' 'MS4' '2N2'  
%For example, use HarmonicNames={'M2' 'S2' 'MM'}; to use M2, S2, and MM only

%Customise the section between the rows of asterisks. 
%Tested against espresso files in John Hunter's OTPS routines - only slight differences (due
%to interpolation schemes and possibly different versions of the OSU data. 

%On 21 Feb 2023, got rid of all the plotting. Moved it to TPXO9v5_plot_ellipses.m, etc.
%On 14 March 2023, changed t0 to be at start of day, same as DSTART in *.in. 

clear
close all

TPXOpath='H:\_mystuff\MODELS\TPXO\DATA\TPXO9_v5\';

%****************CQN Lgrid********************* 
t0=datenum(2023,3,2,0,0,0);
lengthSim=60;  %estimated length of model run (not exact)
fnGRD='H:\_mystuff\_Projects\CQN\Lgrid.nc';
fnOut=['H:\_mystuff\_Projects\CQN\frc_TPXO9v5_Lgrid_' datestr(t0,'ddmmmyyyy') '_0000UT.nc'];
HarmonicNames={ 'M2' 'S2' 'O1' 'K1' 'N2' 'K2' 'P1' 'Q1'};  %Harmonics to be deployed in ROMS, in any order.
%********************************************

disp([fnGRD '     ' datestr(t0,'dd-mmm-yyyy MM:SS')])

% Execute main function
TPXO2ROMS(t0,HarmonicNames,fnGRD,fnOut,lengthSim,TPXOpath)

