function TPXO=readTPXOdata(TPXOfile,HarmonicNames,lon,lat)

%Read TPXO data
%J. Luick, www.austides.com
%With help from C. James

lonmin=min(min(lon));
lonmax=max(max(lon));
latmin=min(min(lat));
latmax=max(max(lat));

bndx=[lon(1,1) lon(end,1) lon(end,end) lon(1,end)];
bndy=[lat(1,1) lat(end,1) lat(end,end) lat(1,end)];

var={'h','U','V'};

count_a30=0;
for n=1:length(HarmonicNames)
    disp(['Harmonic: ' char(HarmonicNames(n))]);
    TPXOfile_grid=TPXOfile.grid.atlas30;
    count_a30=count_a30+1;
    TPXO.('harmonic_a30').harmonic(count_a30)=HarmonicNames(n);
    TPXOfile_elev=TPXOfile.elev.(['TC_' lower(HarmonicNames{n})]);
    TPXOfile_vel=TPXOfile.vel.(['TC_' lower(HarmonicNames{n})]);
    file={TPXOfile_elev,TPXOfile_vel,TPXOfile_vel};
    for i=1:length(var)
        if strcmp(var{i},'h')
            coord='z';
        elseif strcmp(var{i},'U')
            coord='u';
        elseif strcmp(var{i},'V')
            coord='v';
        end
        X=ncread(file{i},['lon_' coord]);
        Y=ncread(file{i},['lat_' coord]);
        I=find((Y>=latmin-0.5)&(Y<=latmax+0.5));
        J=find((X>=lonmin-0.5)&(X<=lonmax+0.5));
        istart=I(1);
        jstart=J(1);
        icount=length(I);
        jcount=length(J);
        
        H=ncread(TPXOfile_grid,['h' coord],[istart jstart],[icount jcount]);
        Z=complex(ncread(file{i},[lower(var{i}) 'Re'],[istart jstart],[icount jcount]),...
            ncread(file{i},[lower(var{i}) 'Im'],[istart jstart],[icount jcount]));
        
        [x,y]=meshgrid(X(J),Y(I));
        if strcmp(var{i},'h')
            z=double(Z)/1000;
        elseif strcmp(var{i},'U') || strcmp(var{i},'V')
            z=double(Z)/10000;
        end
        depth=double(H);
        % is mask necessary here - think it is just to speed things up but
        % can cause problems for small grids.
        mask=inpolygon(x,y,bndx,bndy);
        % remove mask as a factor
        mask=true(size(mask));
        
        TPXO.(var{i}).x_a30=x;
        TPXO.(var{i}).y_a30=y;
        TPXO.(var{i}).depth_a30=depth;
        TPXO.(var{i}).mask_a30=mask;
        if strcmp(var{i},'h')
            TPXO.(var{i}).z_a30(:,:,count_a30)=z;
        else
            TPXO.(var{i}).z_a30(:,:,count_a30)=z./repmat(TPXO.(var{i}).depth_a30,[1 1 size(z,3)]);
        end
    end
end

end

